--[[
	Author:  Azmaedus
	Version: 0.5b
	compatible with game version 6.0.3
	
	Change Log
	----------
	11/29/2014 - 0.1 	Creation of addon
	11/29/2014 - 0.1.1 	Support for tier 1, 2, and 3 garrison (Outpost, Fort, and Garrison)
	12/01/2014 - r8		1st commit to wowace.com (alpha)
	12/02/2014 - r9		Added multi-dimensional table to hold music filename references
	12/26/2014 - r9		Fixed issue with music not playing inside garrison buildings by changing the way to detect if we are inside Lunarfall
	12/27/2014 - r10	2 minute timer added between random playlist items.
						Dropdown music now functional per expansion selected.
						Fixed reload (musiclist) not loading in profile; forgot DB at the end of savedvars .toc
	12/28/2014 - r11	Fixed /reload issue not playing music
	12/29/2014 - 0.2b	1st beta: Fixed error when opening the options UI
	12/29/2014 - 0.3b	Changed from using 2 table design to a single table for holding music information
	12/29/2014 - 0.3.1b	Added Evil Forest 1, 2 and 3 music (Silverpine & Tirisfal)
	12/30/2014 - 0.4b	Code review & optimization (1st pass)
						Re-design of options UI
						Added Audio tab to let users play a wow embedded file by copy/paste into the input control
						Added About tab with relative information
						Localization of music titles and options table.
	12/31/2014 - 0.4.1b	Fixed issue with options UI not showing up on first /gjb command
						Added playlist controls in audio tab
						Added more music to the musictable
						Added slash commands play, prev, next, stop
						Fixed small misc bugs and some naughty coding practices
						Started to implement a zonelist so the user can choose to play the jukebox in multiple locations.
	12/31/2014 - 0.4.2b	Removed unecessary xml frame file to trigger OnLoad event
						Moved audio player in the jukebox tab
						Added a function with enums to manage string colors
						Added more music
	12/31/2014 - 0.4.3b	Fixed issue with zone changing always calling play music.
	01/01/2015 - 0.5b	Changed musictable structure to include multiple files under one music item
						Added Pet Battle music management (Menagerie) processes next song on pet battle start and end
						Separated musictable in it's own file
						Changed the way "Play Sample" works. Click multiple times to cycle through the title's sub-items
						Added music requested by ticket3
												
	Known Bugs
	----------
]]

-- Load the Ace libraries --
GarrisonJukeBox = LibStub("AceAddon-3.0"):NewAddon("GarrisonJukeBox", "AceConsole-3.0", "AceEvent-3.0", "AceTimer-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("GarrisonJukeBox")

GarrisonJukeBox.musictable = {}

-- globals
local gVersion = "0.5b"
local gReleaseDate = "12/31/2014"
local gMusicPlaying = false 	-- is the music currently playing
local gMusicIndex = 1			-- current item index of table musicfiles
local gMusicIndexIn = 1			-- current item index of sub-items inside the musictable structure
local gMaxMusic = 0				-- number of items in musicfiles table
local gMaxMusicIn = 0			-- number of sub-items in musictable structure
local gOnLoadMusicTimer = 5		-- HACK!!! wait n seconds when PLAYYER_LOGIN is triggered before playing music (make sure Blizz level loading script doesn't override PlayMusic() call)
local LUNARFALL = 971			-- zone id of Lunarfall
local gPrevZone = 0				-- holder for comparison when changing zones (in case going into same zone) O.o
local gPetBattleEnabled = false -- Pet battle event state
local gSampleIndex = 1			-- current index of sub-item for playing sample music
local gSampleLastIndex = 1		-- last index used to play sub-item sample music
local gSamplePlayed = ""		-- expansion+title string of last played smaple music

-- function to set the color of text provided
COLORS = {
	SG_GREEN = "|cff38ce39",
	SG_BLUE = "|cff539ce8",
	SG_WHITE = "|cffffffff",
	SG_BLACK = "|cff000000",
}
function setTextColor(s,c)
	if c ~= nil or c ~= "" then
		-- make sure the color exist, if not, set to white
		if COLORS[c] == nil then
			assert(COLORS[c], c .. L["ERROR_INVALID_COLOR"])
			c = COLORS["SG_WHITE"]
		end
		
		s = COLORS[c] .. s .. "|r"
	end
	
	return s
end

-- temp storage for select vars
local expac = "i1wow"
local music = 1
local jukebox = ""
local playsoundfile = ""
local doubleslashes = true
local zone = "i1zone"
local zonebox = ""

-- Create the default settings for this addon --
local defaults = { 
    profile =  {
		musiclist = {},
		zonelist = {"Lunarfall"},
		shuffle = false,
		petbattle = true,
	},
}

-- Get localization
local L = LibStub("AceLocale-3.0"):GetLocale("GarrisonJukeBox")

-- table holding zone info (name, id)
local zonetable = {
	{"Lunarfall", 971},
	{"Ashran", 978},
	{"Stormshield", 1009},
	{"Warspear", 1011},
}

-- Create the options variable to use in the config screen --
local options = {
	name = L["OPT_JUKEBOX_OPTIONS"],
	handler = GarrisonJukeBox,
	type = "group",
	childGroups = "tab",
	args = {
		grp1jukebox = {
			name = L["OPT_JUKEBOX"],
			desc = L["OPT_JUKEBOX_DESC"],
			type = "group",
			order = 1,
			args = {
				hdrjukebox = {
					name = L["SEL_JUKEBOX"],
					type = "header",
					order = 5,
				},
				expac = {
					type = "select",
					name = L["SEL_EXPANSION"],
					desc = L["SEL_EXPANSION_DESC"],
					style = "dropdown",
					values = "GetExpanssions",
					set = function(info, value)
						expac = value
					end,
					get = "GetExpac",
					width = "normal",
					order = 10,
				},
				music = {
					type = "select",
					name = L["SEL_MUSIC"],
					desc = L["SEL_MUSIC_DESC"],
					style = "dropdown",
					values = "GetCurExpacMusicList",
					set = function(info, value)
						music = value
					end,
					get = "GetMusic",
					width = "normal",
					order = 15,
				},
				musicadd = {
					type = "execute",
					name = L["CMD_ADD"],
					desc = L["CMD_ADD_DESC"],
					func = function()
						local xps = GarrisonJukeBox:GetExpanssions()
						local xp = xps[GarrisonJukeBox:GetExpac()]
						local mus = GarrisonJukeBox:GetCurExpacMusicList()
						local mu = mus[GarrisonJukeBox:GetMusic()]
						
						-- TODO: Will we allow duplicates?
						table.insert(GarrisonJukeBox.db.profile.musiclist, xp .. "/" .. mu)
						jukebox = xp .. "/" .. mu
					end,
					width = "half",
					order = 20,
				},
				descspace1 = {
					name = " ",
					type = "description",
					width = "full",
					fontSize = "small",
					order = 25,
				},
				cmdplaysamplemusic = {
				-- press multiple times to play next sub-item in list
					type = "execute",
					name = L["OPT_PLAYSAMPLE"],
					desc = L["OPT_PLAYSAMPLE_DESC"],
					func = function()
						local xps = GarrisonJukeBox:GetExpanssions()
						local xp = xps[GarrisonJukeBox:GetExpac()]
						local mus = GarrisonJukeBox:GetCurExpacMusicList()
						local mu = mus[GarrisonJukeBox:GetMusic()]
						local ft = GarrisonJukeBox:MusicListFromJukeBoxItem(xp .. "/" .. mu) -- gets a table of sub-items to play from musictable
						
						-- check if there are sub-items
						if #ft > 0 then
							-- check what sub-item we play
							if gSamplePlayed ~= expac .. music then
								gSampleIndex = 1
								gSamplePlayed = expac .. music
							else
								gSampleIndex = gSampleIndex + 1
								if gSampleIndex > #ft then
									gSampleIndex = 1
								end
							end
							
							-- play music
							StopMusic()
							gMusicPlaying = false
							GarrisonJukeBox:CancelTimer(GarrisonJukeBox.musicTimer)
							PlayMusic(GarrisonJukeBox.musictable[expac][music].files[gSampleIndex][1])
							GarrisonJukeBox:Print(L["SAMPLE_MUSIC"] .. xp .. "/" .. mu)
							GarrisonJukeBox:Print(L["SAMPLE_FILE"] .. GarrisonJukeBox.musictable[expac][music].files[gSampleIndex][1])
						end
					end,
					width = "normal",
					order = 30,
				},
				cmdstopsound = {
					type = "execute",
					name = L["CMD_STOP"],
					func = function()
						StopMusic()
						GarrisonJukeBox:ProcessInfo()
					end,
					width = "half",
					order = 35,
				},
				descspace2 = {
					name = " ",
					type = "description",
					width = "full",
					fontSize = "small",
					order = 40,
				},
				musiclist = {
					type = "select",
					name = L["SEL_JUKEBOX"],
					desc = L["SEL_JUKEBOX_DESC"],
					style = "dropdown",
					values = function()
						return GarrisonJukeBox.db.profile.musiclist
					end,
					set = function(info, value)
						jukebox = value
					end,
					get = function(info)
						return jukebox
					end,
					width = "double",
					order = 45,
				},
				musicdelete = {
					type = "execute",
					name = L["CMD_REMOVE"],
					desc = L["CMD_REMOVE_DESC"],
					func = function()
						GarrisonJukeBox.db.profile.musiclist[jukebox] = nil
					end,
					width = "half",
					order = 50,
				},
				musicdeleteall = {
					type = "execute",
					name = L["CMD_REMOVEALL"],
					desc = L["CMD_REMOVEALL_DESC"],
					func = function()
						GarrisonJukeBox.db.profile.musiclist = {}
						jukebox = ""
					end,
					width = "normal",
					order = 55,
				},
				descspaceshuffle = {
					name = "",
					type = "description",
					width = "full",
					fontSize = "small",
					order = 60,
				},
				shuffle = {
					type = "toggle",
					name = L["TOG_SHUFFLE"],
					desc = L["TOG_SHUFFLE_DESC"],
					set = function(info, value)
						GarrisonJukeBox.db.profile.shuffle = value
					end,
					get = function(info)
						return GarrisonJukeBox.db.profile.shuffle
					end,

					width = "normal",
					order = 65,
				},
				petbattle = {
					type = "toggle",
					name = L["TOG_PETBATTLE"],
					desc = L["TOG_PETBATTLE_DESC"],
					set = function(info, value)
						GarrisonJukeBox.db.profile.petbattle = value
					end,
					get = function(info)
						return GarrisonJukeBox.db.profile.petbattle
					end,

					width = "normal",
					order = 67,
				},
				hdrselection = {
					name = L["HDR_ZONES"],
					type = "header",
					order = 70,
				},
				i1zone = {
					type = "select",
					name = L["SEL_ZONE"],
					desc = L["SEL_ZONE_DESC"],
					style = "dropdown",
					values = "GetZones",
					set = function(info, value)
						zone = value
					end,
					get = function(info)
						return zone
					end,
					width = "normal",
					order = 75,
				},
				zoneadd = {
					type = "execute",
					name = L["CMD_ADD"],
					desc = L["CMD_ADDZONE_DESC"],
					func = function()
						table.insert(GarrisonJukeBox.db.profile.zonelist, zonetable[zone][1])
					end,
					width = "half",
					order = 80,
				},
				descspacezone = {
					name = "",
					type = "description",
					width = "full",
					fontSize = "small",
					order = 85,
				},
				zonelist = {
					type = "select",
					name = L["SEL_YOUR_ZONES"],
					desc = L["SEL_YOUR_ZONES_DESC"],
					style = "dropdown",
					values = function()
						return GarrisonJukeBox.db.profile.zonelist
					end,
					set = function(info, value)
						zonebox = value
					end,
					get = function(info)
						return zonebox
					end,
					width = "double",
					order = 90,
				},
				zonedelete = {
					type = "execute",
					name = L["CMD_REMOVE"],
					desc = L["CMD_REMOVE_DESC"],
					func = function()
						GarrisonJukeBox.db.profile.zonelist[zonebox] = nil
					end,
					width = "half",
					order = 95,
				},
				zonedeleteall = {
					type = "execute",
					name = L["CMD_REMOVEALL"],
					desc = L["CMD_REMOVEALL_DESC"],
					func = function()
						GarrisonJukeBox.db.profile.zonelist = {}
						zonebox = ""
					end,
					width = "normal",
					order = 100,
				},			
				hdrplayer = {
					name = L["HDR_AUDIOPLAYER"],
					type = "header",
					order = 105,
				},
				play = {
					type = "execute",
					name = L["CMD_PLAY"],
					func = function()
						StopMusic()
						GarrisonJukeBox:ProcessInfo()
					end,
					width = "half",
					order = 110,
				},
				prev = {
					type = "execute",
					name = L["CMD_PREV"],
					func = function()
						StopMusic()
						
						gMusicIndex	= gMusicIndex - 1
						if gMusicIndex < 1 then
							gMusicIndex = gMaxMusic
						end
						
						GarrisonJukeBox:ProcessInfo()
					end,
					width = "half",
					order = 115,
				},
				next = {
					type = "execute",
					name = L["CMD_NEXT"],
					func = function()
						StopMusic()
						GarrisonJukeBox:ProcessInfo()
					end,
					width = "half",
					order = 120,
				},
				stop = {
					type = "execute",
					name = L["CMD_STOP"],
					func = function()
						StopMusic()
					end,
					width = "half",
					order = 125,
				},
			},
		},
		grp2audio = {
			name = L["OPT_AUDIO"],
			desc = L["OPT_AUDIO_DESC"],
			type = "group",
			order = 10,
			--disabled = true,
			args = {
				txtplaysound = {
					name = L["INP_WOWAUDIOFILE"],
					type = "input",
					width = "double",
					set = function(info, value)
						playsoundfile = value
					end,

					get = function(info)
						return playsoundfile
					end,
					order = 10,
				},
				cmdplaysound = {
					type = "execute",
					name = L["CMD_PLAY"],
					func = function()
						if doubleslashes == true then
							local s = "" -- temporary string holding newly created sound filename
							local i1, i2 = 1
							local l = strlen(playsoundfile)
							
							-- loop through the filename's characters to find double slashes
							while i1 <= l do
								local i2 = strfind(playsoundfile, "\\\\", i1)
								if i2 ~= nil then
									s = s .. strsub(playsoundfile, i1, i2-1) .. "\\"
									i1 = i2+2
								else
									s = s .. strsub(playsoundfile, i1)
									playsoundfile = s
									break
								end
							end
						end
						
						StopMusic()
						gMusicPlaying = false
						GarrisonJukeBox:CancelTimer(GarrisonJukeBox.musicTimer)
						PlayMusic(playsoundfile)
						GarrisonJukeBox:Print(L["NOW_PLAYING"] .. playsoundfile)
					end,
					width = "half",
					order = 11,
				},
				cmdstopsound = {
					type = "execute",
					name = L["CMD_STOP"],
					func = function()
						StopMusic()
						GarrisonJukeBox:ProcessInfo()
					end,
					width = "half",
					order = 12,
				},
				doubleslashes = {
					type = "toggle",
					name = L["TOG_SLASHES"],
					desc = L["TOG_SLASHES_DESC"],

					set = function(info, value)
						doubleslashes = value
					end,

					get = function(info)
						return doubleslashes
					end,

					width = "full",
					order = 50,
				},
			},
		},
		grp3about = {
			name = L["OPT_ABOUT"],
			desc = "",
			type = "group",
			order = 20,
			args = {
				desctitle = {
					name = setTextColor(L["ADDON_NAME"] .. " " .. gVersion, "SG_GREEN"),
					type = "description",
					width = "full",
					fontSize = "medium",
					order = 1,
				},
				desctitle2 = {
					name = setTextColor(L["ADDON_RELEASE"] .. gReleaseDate, "SG_GREEN"),
					type = "description",
					width = "full",
					fontSize = "medium",
					order = 2,
				},
				descauthor = {
					name = setTextColor(L["ADDON_AUTHOR"] .. " " .. "Azmaedus", "SG_BLUE"),
					type = "description",
					width = "full",
					fontSize = "medium",
					order = 10,
				},
				descspace1 = {
					name = " ",
					type = "description",
					width = "full",
					fontSize = "large",
					order = 20,
				},
				descslashhdr = {
					name = L["ABOUT_SLASHCMD_TITLE"],
					type = "description",
					width = "full",
					fontSize = "medium",
					order = 30,
				},
				descslashplay = {
					name = L["ABOUT_SLASHCMD_PLAY"],
					type = "description",
					width = "full",
					fontSize = "small",
					order = 40,
				},
				descslashprev = {
					name = L["ABOUT_SLASHCMD_PREV"],
					type = "description",
					width = "full",
					fontSize = "small",
					order = 50,
				},
				descslashnext = {
					name = L["ABOUT_SLASHCMD_NEXT"],
					type = "description",
					width = "full",
					fontSize = "small",
					order = 60,
				},
				descslashstop = {
					name = L["ABOUT_SLASHCMD_STOP"],
					type = "description",
					width = "full",
					fontSize = "small",
					order = 70,
				},
--[[				deschowto = {
					name = "Howto",
					type = "description",
					width = "full",
					fontSize = "medium",
					order = 30,
				},
				desccont1 = {
					name = "Jukebox tab",
					type = "description",
					width = "full",
					fontSize = "small",
					order = 40,
				},]]
			},
		},
		next = {
			type = "execute",
			name = "",
			hidden = true,
			func = function()
				StopMusic()
				GarrisonJukeBox:ProcessInfo()
			end,
			width = "half",
			order = 2000,
		},
		stop = {
			type = "execute",
			name = "",
			hidden = true,
			func = function()
				StopMusic()
			end,
			width = "half",
			order = 3000,
		},
		play = {
			type = "execute",
			name = "",
			hidden = true,
			func = function()
				StopMusic()
				GarrisonJukeBox:ProcessInfo()
			end,
			width = "half",
			order = 4000,
		},
		prev = {
			type = "execute",
			name = "",
			hidden = true,
			func = function()
				StopMusic()
				
				gMusicIndex	= gMusicIndex - 1
				if gMusicIndex < 1 then
					gMusicIndex = gMaxMusic
				end
				
				GarrisonJukeBox:ProcessInfo()
			end,
			width = "half",
			order = 5000,
		},
	},
}

-- function to get a table of all expansion/category names with keys that match the options table
function GarrisonJukeBox:GetExpanssions()
	return {
		i1wow = EXPANSION_NAME0,
		i2bc = EXPANSION_NAME1,
		i3wotlk = EXPANSION_NAME2,
		i4cata = EXPANSION_NAME3,
		i5mop = EXPANSION_NAME4,
		i6wod = EXPANSION_NAME5,
		i7events = L["EXP_WCEVENTS"],
	}
end

-- options table functions that may be called from more than one component
function GarrisonJukeBox:GetCurExpacMusicList()
	local tbl = GarrisonJukeBox.musictable[self:GetExpac()]
	local t = {}

	for k, v in ipairs(tbl) do
		table.insert(t, k, v["name"])
	end
	
	return t
end

function GarrisonJukeBox:GetExpac(info)
	return expac
end

function GarrisonJukeBox:GetMusic(info)
	return music
end

function GarrisonJukeBox:GetZones()
	local tbl = {}
	for i = 1, #zonetable do
		table.insert(tbl, zonetable[i][1])
	end
	return tbl
end

--[[=============================================================
						OnInitialize
    =============================================================]]
function GarrisonJukeBox:OnInitialize()
	GarrisonJukeBox:RegisterEvent("PLAYER_ENTERING_WORLD", "OnPEWEvent")
	GarrisonJukeBox:RegisterEvent("ZONE_CHANGED_NEW_AREA", "OnZoneEvent")
	GarrisonJukeBox:RegisterEvent("ZONE_CHANGED_INDOORS", "OnZoneEvent")
	GarrisonJukeBox:RegisterEvent("PET_BATTLE_OPENING_START", "OnPetBattleStart")
	GarrisonJukeBox:RegisterEvent("PET_BATTLE_OVER", "OnPetBattleEnd")
	GarrisonJukeBox:RegisterEvent("ZONE_CHANGED", "OnZoneEvent")
		
	GarrisonJukeBox.db = LibStub("AceDB-3.0"):New("GarrisonJukeBoxDB", defaults, true)
	LibStub("AceConfig-3.0"):RegisterOptionsTable("GarrisonJukeBoxDB", options, "gjb")
	GarrisonJukeBox.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("GarrisonJukeBoxDB", "Garrison JukeBox")
	self:RegisterChatCommand("gjb", "ChatCommand")

	gMusicIndex = 1
	gMusicIndexIn = 1
	gMusicPlaying = false
	gMaxMusic = 0
	gMaxMusicIn = 0
	gPrevZone = 0
	self.musicTimer = nil
	
	self:Print(L["ADDON_NAME"] .. " " .. gVersion .. " " .. L["ADDON_LOADED"])
end

-- -------------------------------------------
-- Events
-- -------------------------------------------
function GarrisonJukeBox:OnPEWEvent(event, ...)
	StopMusic()
	gMusicPlaying = false
	self.musicTimer = self:ScheduleTimer("TimerEvent", gOnLoadMusicTimer)
end
function GarrisonJukeBox:TimerEvent()
	self:ProcessInfo()
end

function GarrisonJukeBox:OnZoneEvent(event, ...)
	if gPrevZone ~= GetCurrentMapAreaID() then
		gPrevZone = GetCurrentMapAreaID()
		self:ProcessInfo()
	end
end

function GarrisonJukeBox:OnPetBattleStart(event, ...)
	if self:IsInZoneList(GetCurrentMapAreaID()) then
		gPetBattleEnabled = true
		self:ProcessInfo()
	end
end

function GarrisonJukeBox:OnPetBattleEnd(event, ...)
	if self:IsInZoneList(GetCurrentMapAreaID()) then
		gPetBattleEnabled = false
		self:ProcessInfo()
	end
end

-- -------------------------------------------
-- slashcmd
-- -------------------------------------------
function GarrisonJukeBox:ChatCommand(input)
	-- Open dialog if no parameters, else do something with the parameters
	if not input or input:trim() == "" then
		LibStub("AceConfigDialog-3.0"):Open("GarrisonJukeBoxDB")
		--InterfaceOptionsFrame_OpenToCategory(GarrisonJukeBox.optionsFrame)
		-- InterfaceOptionsFrame_OpenToCategory seems to not function immediately. Firts attempt == Blizz options frame. Second attempt == gjb options frame ???
	else
		LibStub("AceConfigCmd-3.0").HandleCommand(GarrisonJukeBox, "gjb", "GarrisonJukeBoxDB", input)
	end
end

-- -------------------------------------------
-- function to set the musictable from musictable.lua
-- -------------------------------------------
function GarrisonJukeBox:SetMusicTable(tbl)
	self.musictable = tbl
end

-- -------------------------------------------
-- function called to determine if music needs to be played or stopped
-- -------------------------------------------
function GarrisonJukeBox:ProcessInfo()
	local playstate = false
	if self:IsInZoneList(GetCurrentMapAreaID()) then
		if gPetBattleEnabled == true then
			if GarrisonJukeBox.db.profile.petbattle == true then
				playstate = true
			end
		else
			playstate = true
		end
	end
	
	if playstate == true then
		gMaxMusic = table.getn(GarrisonJukeBox.db.profile.musiclist)
		if gMaxMusic > 0 then
			self:PlayMusicList()
		end
	else
		if gMusicPlaying == true then
			StopMusic()
			gMusicPlaying = false
			self:CancelTimer(self.musicTimer)
		end
	end
end

-- gets the zone name by id
function GarrisonJukeBox:GetZoneNameByID(id)
	for _, v in ipairs(zonetable) do
		if v[2] == id then
			return v[1]
		end
	end
	return
end

-- verifies if the submitted zone name is in the selected zones (zonelist)
function GarrisonJukeBox:IsInZoneList(id)
	for k, v in ipairs(GarrisonJukeBox.db.profile.zonelist) do
		if v == self:GetZoneNameByID(id) then
			return true
		end
	end
	return false
end

-- -------------------------------------------
-- Table Invert for query of key
-- -------------------------------------------
function table_invert(t)
   local s={}
   for k,v in pairs(t) do
     s[v]=k
   end
   return s
end

-- -------------------------------------------
-- break appart the musiclist item to find out what file to play in the musicfile table
-- returns a table representing the music info
-- -------------------------------------------
function GarrisonJukeBox:MusicListFromJukeBoxItem(s)
	local idx = 0
	
	-- get the expansion key
	local b = strfind(s, "/")
	local ns = strsub(s, 1, b-1)
	local xp = self:GetExpanssions() -- 
	local xpi = table_invert(xp)
	idx = xpi[ns]

	-- get music info
	ns = strsub(s, b+1)
	local mt = self.musictable[idx] -- get table of music infos relative to the expansion
	
	-- loop through tables to find the music info
	for k, v in ipairs(mt) do
		if v["name"] == ns then
			return v["files"]
		end
	end
end

-- -------------------------------------------
-- function to play an item in the musiclist table
-- -------------------------------------------
function GarrisonJukeBox:PlayMusicList()
	self:CancelTimer(self.musicTimer)
	
	-- check if the list has shrunk since last pass and index is greater than number of list items
	if gMusicIndex > gMaxMusic then
		gMusicIndex = gMaxMusic
	end
	
	-- check if the playlist is in shuffle mode, if so, set a random index
	if GarrisonJukeBox.db.profile.shuffle == true then
		gMusicIndex = math.random(1, gMaxMusic)
	end
	
	-- get table of music files to play
	local mli = GarrisonJukeBox.db.profile.musiclist[gMusicIndex] -- get the string representing what title should be playing
	local ft = self:MusicListFromJukeBoxItem(mli) -- gets a table of sub-items to play from musictable

	-- get random index of sub-item to play
	gMaxMusicIn = table.getn(ft) -- get number of sub-items
	gMusicIndexIn = math.random(1, gMaxMusicIn)
	local info = ft[gMusicIndexIn]
		
	-- stop and play
	StopMusic()
	PlayMusic(info[1])
	self:Print(L["PLAYING"] .. "#" .. gMusicIndex .. " - " .. GarrisonJukeBox.db.profile.musiclist[gMusicIndex])
	gMusicPlaying = true
	self.musicTimer = self:ScheduleTimer("TimerEvent", info[2])

	-- increment index after item is playing
	if gMusicIndex == gMaxMusic then
		gMusicIndex = 1
	else
		gMusicIndex = gMusicIndex + 1
	end
end
