-- Get localization
local L = LibStub("AceLocale-3.0"):GetLocale("GarrisonJukeBox")

-- table holding music info (name, file, length)
local musictable = {
	-- Classic
	i1wow = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\GlueScreenMusic\\wow_main_theme.mp3", 161},
			},
		},
		{
			name = L["TITLE_EVILFOREST"],
			files = {
				{"Sound\\Music\\ZoneMusic\\EvilForest\\NightEvilForest02.mp3", 75},
			},
		},
		{
			name = L["TITLE_MOLTENCORE"],
			files = {
				{"Sound\\Music\\Musical Moments\\battle\\battle01.mp3", 48},
			},
		},
		{
			name = L["TITLE_ENCHANTEDFOREST"],
			files = {
				{"Sound\\Music\\ZoneMusic\\EnchantedForest\\EnchantedForest01.mp3", 50},
			},
		},
		{
			name = L["TITLE_DARNASSUS"],
			files = {
				{"Sound\\Music\\CityMusic\\Darnassus\\Darnassus Walking 1.mp3", 85},
			},
		},
		{
			name = L["TITLE_GNOMERAGON"],
			files = {
				{"Sound\\Music\\CityMusic\\Gnomeragon\\gnomeragon01-zone.mp3", 64},
			},
		},
		{
			name = L["TITLE_IRONFORGE"],
			files = {
				{"Sound\\Music\\CityMusic\\Ironforge\\IronForge Walking 01.mp3", 123},
			},
		},
		{
			name = L["TITLE_ORGRIMMAR"],
			files = {
				{"Sound\\Music\\CityMusic\\Orgrimmar\\orgrimmar01-zone.mp3", 68},
				{"Sound\\Music\\CityMusic\\Orgrimmar\\orgrimmar02-zone.mp3", 62},
			},
		},
		{
			name = L["TITLE_STORMWIND"],
			files = {
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind07-zone.mp3", 87},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind_highSeas-moment.mp3", 133},
			},
		},
		{
			name = L["TITLE_THUNDERBLUFF"],
			files = {
				{"Sound\\Music\\CityMusic\\Thunderbluff\\Thunderbluff Walking 03.mp3", 121},
			},
		},
		{
			name = L["TITLE_UNDERCITY"],
			files = {
				{"Sound\\Music\\CityMusic\\Undercity\\undercity02-zone.mp3", 85},
			},
		},
		{
			name = L["TITLE_BARRENS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\BarrenDry\\DayBarrenDry01.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\BarrenDry\\NightBarrenDry01.mp3", 67},
			},
		},
	},

	-- The Burning Crusade
	i2bc = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\GlueScreenMusic\\BC_main_theme.mp3", 226},
			},
		},
		{
			name = L["TITLE_SUNWELL"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_SunwellFlybyUni01.mp3", 57},
			},
		},
		{
			name = L["TITLE_ESCDURNHOLDE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_EscapeDurnIntroUni.mp3", 112},
			},
		},
		{
			name = L["TITLE_HYJAL"],
			files = {
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalk8Uni.mp3", 70},
			},
		},
		{
			name = L["TITLE_LAMENTOTHIGHBORNE"],
			files = {
				{"Sound\\Music\\GlueScreenMusic\\BCCredits_Lament_of_the_Highborne.mp3", 171},
			},
		},
		{
			name = L["TITLE_SHORELARAN"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_ShorelAranWalkUni01.mp3", 87},
			},
		},
		{
			name = L["TITLE_AZUREMIST"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni01.mp3", 206},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni03.mp3", 103},
			},
		},
		{
			name = L["TITLE_EXODAR"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni01.mp3", 109},
			},
		},
		{
			name = L["TITLE_BLOODMIST"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni01r.mp3", 126},
			},
		},
		{
			name = L["TITLE_BLACKTEMPLE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ArrivalWalkHero01.mp3", 164},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkHero09.mp3", 74},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_KaraborWalkUni04.mp3", 126},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkHero01.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkHero01.mp3", 131},
			},
		},
	},
	
	-- Wrath of the Lich King
	i3wotlk = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\GlueScreenMusic\\WotLK_main_title.mp3", 544},
			},
		},
		{
			name = L["TITLE_STORMPEAKS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\StormPeaks\\SP_GeneralWalkB_Day02.mp3", 82},
			},
		},
		{
			name = L["TITLE_DALARAN"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Dalaran\\DC_GeneralWalkUni01.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Dalaran\\DC_GeneralWalkUni02.mp3", 42},
				{"Sound\\Music\\ZoneMusic\\Dalaran\\DC_GeneralWalkUni03.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\Dalaran\\DC_GeneralWalkUni04.mp3", 88},
			},
		},
		{
			name = L["TITLE_ICECROWNGLACIER"],
			files = {
				{"Sound\\Music\\ZoneMusic\\IcecrownGlacier\\IC_GeneralIntro_01.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\IcecrownGlacier\\IC_GeneralIntro_02.mp3", 56},
				{"Sound\\Music\\ZoneMusic\\IcecrownGlacier\\IC_GeneralIntro_03.mp3", 57},
			},
		},
		{
			name = L["TITLE_CRYSTALSONGFOREST"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni01.mp3", 113},
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni02.mp3", 98},
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni03.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni04.mp3", 113},
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni05.mp3", 107},
			},
		},
		{
			name = L["TITLE_DRAGONBLIGHT"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Dragonblight\\DB_GeneralIntro_01.mp3", 92},
				{"Sound\\Music\\ZoneMusic\\Dragonblight\\DB_GeneralIntro_02.mp3", 93},
				{"Sound\\Music\\ZoneMusic\\Dragonblight\\DB_GeneralIntro_03.mp3", 92},
				{"Sound\\Music\\ZoneMusic\\Dragonblight\\DB_GeneralIntro_04.mp3", 92},
			},
		},
		{
			name = L["TITLE_HOWLINGFJORD"],
			files = {
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni01.mp3", 30},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni02.mp3", 47},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni03.mp3", 52},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni04.mp3", 26},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni05.mp3", 22},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni06.mp3", 41},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni07.mp3", 23},
			},
		},
		{
			name = L["TITLE_SCHOLAZARBASIN"],
			files = {
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay01.mp3", 175},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay02.mp3", 114},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay03.mp3", 105},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay04.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay05.mp3", 123},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay06.mp3", 142},
			},
		},
		{
			name = L["TITLE_ESCAPEFROMARTHAS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_HallsofChase.mp3", 106},
			},
		},
		{
			name = L["TITLE_LADYORLICH"],
			files = {
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_LadyortheLich.mp3", 75},
			},
		},
		{
			name = L["TITLE_ICEFORTRESS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress.mp3", 133},
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress1.mp3", 153},
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress2.mp3", 105},
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress3.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress4.mp3", 106},
			},
		},
	},
	
	-- Cataclysm
	i4cata = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_Shattering_UU01.mp3", 725},
			},
		},
		{
			name = L["TITLE_NIGHTELVES"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_NightElves_GU01.mp3", 160},
			},
		},
		{
			name = L["TITLE_AFTERMATH"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_Aftermath_UU01.mp3", 125},
			},
		},
		{
			name = L["TITLE_CORRUPTED_DRAGONBLIGHT"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_CorruptedDragonblight_UU01.mp3", 122},
			},
		},
		{
			name = L["TITLE_DRAGONSOUL"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_DragonSoulA_Moment_04.mp3", 60},
				{"Sound\\Music\\cataclysm\\MUS_43_Gunships_Hero_UU01.mp3", 189},
			},
		},
		{
			name = L["TITLE_FANGS_OT_FATHER"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_FangsOfTheFatherA_Hero_UU01.mp3", 121},
			},
		},
		{
			name = L["TITLE_NIGHTWALK"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_NightWalk_UU02.mp3", 60},
			},
		},
		{
			name = L["TITLE_THRALLBATTLE"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_ThrallEarthWarder_UU01.mp3", 62},
			},
		},
		{
			name = L["TITLE_TWILIGHTSHAMMER"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_TwilightsHammer_UU01.mp3", 113},
			},
		},
		{
			name = L["TITLE_WARSHIPS"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_Warships_Hero_01.mp3", 90},
			},
		},
		{
			name = L["TITLE_WELLOFETERNITY"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_WellOfEternity_Hero_UU01.mp3", 84},
			},
		},
		{
			name = L["TITLE_ZINAZSHARI"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_ZinAzshari_Hero_UU01.mp3", 177},
			},
		},
		{
			name = L["TITLE_RAGE_OT_FIRELANDS"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_AdventureA_Hero_UU01.mp3", 141},
			},
		},
		{
			name = L["TITLE_ALLIANCE_ONE_HERO"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_AllianceHero_UU01.mp3", 195},
			},
		},
	},
	
	-- Mists of Pandaria
	i5mop = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_HeartofPandaria_01.mp3", 480},
			},
		},
		{
			name = L["TITLE_WANDERINGISLE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\WanderingIsle\\MUS_50_WanderingIsleB_Hero_UU01.mp3", 135},
			},
		},
		{
			name = L["TITLE_VALLEY4WINDS"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_BalloonRide_Hero_01.mp3", 165},
			},
		},
		{
			name = L["TITLE_SONG_LIULANG"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_SongofLiulang_VOX_Hero_01.mp3", 170},
			},
		},
		{
			name = L["TITLE_SERPENTRACE"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_SerpentRiders_SerpentRace.mp3", 238},
			},
		},
		{
			name = L["TITLE_GINSUVALOR"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_ShadoPan_A_Hero_03.mp3", 172},
			},
		},
		{
			name = L["TITLE_WAYOTMONK"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_Monk_Windwalker_A_01.mp3", 157},
			},
		},
	},
	
	-- Warlords of Draenor
	i6wod = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_ASiegeofWorlds_MainTitle.mp3", 726},
			},
		},
		{
			name = L["TITLE_A_HEROS_SACRIFICE"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_AHerosSacrifice_v1.mp3", 116},
			},
		},
		{
			name = L["TITLE_A_LIGHT_IT_DARKNESS"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_ALightintheDarkness_v1.mp3", 155},
			},
		},
		{
			name = L["TITLE_SPIRES_OF_ARAK"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_Arak2_H.mp3", 157},
			},
		},
		{
			name = L["TITLE_DRAENOR_ARMY"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_Army_A.mp3", 142},
			},
		},
		{
			name = L["TITLE_DRAENOR_FREEDOM"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_BFreedom_H2.mp3", 107},
			},
		},
		{
			name = L["TITLE_DRAENOR_BLACKROCK"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_Blackrock_H.mp3", 188},
			},
		},
	},
	
	-- Warcraft III
	i7events = {
		{
			name = L["TITLE_POWEROTHORDE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\DMF_L70ETC01.mp3", 282},
			},
		},
		{
			name = L["TITLE_FIREFESTIVAL"],
			files = {
				{"Sound\\Music\\WorldEvents\\AllianceFirepole.mp3", 68},
			},
		},
		{
			name = L["TITLE_ARGENTTOURNY"],
			files = {
				{"Sound\\Music\\ZoneMusic\\ArgentTournament\\AT_JoustEvent.mp3", 123},
			},
		},
	},
}

local GJB = LibStub("AceAddon-3.0"):GetAddon("GarrisonJukeBox")
if not GJB then return end
GJB:SetMusicTable(musictable)